@@ -86,7 +86,7 @@
 #define KHOLIDAYS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KHOLIDAYS_NO_DEPRECATED
-#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KHOLIDAYS_NO_DEPRECATED_WARNINGS
 #  define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KHOLIDAYS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KHOLIDAYS_NO_DEPRECATED
-#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KHOLIDAYS_NO_DEPRECATED_WARNINGS
 #  define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
